@@ -1,6 +1,6 @@
 from flask import Flask, jsonify
 from flask_cors import CORS
-from flask import request
+from flask import request, Response
 import time
 import gevent.pywsgi
 
@@ -65,8 +65,14 @@ class FlaskServer(IQRServer, FlaskContextCreator, QRLogger):
                 return result.result
             if result.status_code == 200:
                 return jsonify(result.result)
-            else:
-                return result.result, result.status_code
+
+            resp = Response(result.result, result.status_code)
+
+            if result.headers is not None:
+                for header, value in result.headers.items():
+                    resp.headers[header] = value
+            return resp
+
         except Exception as e:
             super().info(in_msg)
             super().exception(e)
